@@ -56,6 +56,9 @@ logger = logging.getLogger(__name__)  # pylint: disable=invalid-name
 DLT_EMPTY_FILE_ERROR = "DLT TRACE FILE IS EMPTY"
 cDLT_FILE_NOT_OPEN_ERROR = "Could not open DLT Trace file (libdlt)"  # pylint: disable=invalid-name
 
+DLT_UDP_MULTICAST_FD_BUFFER_SIZE = int(os.environ.get("PYDLT_UDP_MULTICAST_FD_BUFFER_SIZE", 2 * (2**20)))  # 2 Mb
+DLT_UDP_MULTICAST_BUFFER_SIZE = int(os.environ.get("PYDLT_UDP_MULTICAST_BUFFER_SIZE", 8 * (2**20)))  # 8 Mb
+
 
 class cached_property(object):  # pylint: disable=invalid-name
     """
@@ -865,13 +868,23 @@ class cDLTFile(ctypes.Structure):  # pylint: disable=invalid-name
 
 
 class DLTClient(cDltClient):
-    """DLTClient class takes care about correct initialization and
-    cleanup
-    """
+    """DLTClient class takes care about correct initialization and cleanup"""
 
     verbose = 0
 
     def __init__(self, **kwords):
+        """Initialize a DLTClient.
+
+        :param servIP: Optional[str] - dlt server IP.
+        :param hostIP: Optional[str] - Only available for udp multicast mode.
+            Set host interface address.
+        :param port: Optional[int] - dlt tcp daemon port.
+        :param verbose: Optional[bool] - Enable verbose output.
+        :param udp_fd_buffer_size_bytes: Optional[int] - Only available for udp
+            multicast mode. Set the UDP buffer size through setsockopt (unit: bytes).
+        :param udp_buffer_size_bytes: Optional[int] - Only available for udp
+            multicast mode. Set the DltReceiver's buffer size (unit: bytes).
+        """
         self.is_udp_multicast = False
         self.verbose = kwords.pop("verbose", 0)
         if dltlib.dlt_client_init(ctypes.byref(self), self.verbose) == DLT_RETURN_ERROR:
@@ -915,6 +928,9 @@ class DLTClient(cDltClient):
         # it ourselves elsewhere
         self.port = kwords.get("port", DLT_DAEMON_TCP_PORT)
 
+        self._udp_fd_buffer_size_bytes = kwords.get("udp_fd_buffer_size_bytes", DLT_UDP_MULTICAST_FD_BUFFER_SIZE)
+        self._udp_buffer_size_bytes = kwords.get("udp_buffer_size_bytes", DLT_UDP_MULTICAST_BUFFER_SIZE)
+
     def connect(self, timeout=None):
         """Connect to the server
 
@@ -929,7 +945,8 @@ class DLTClient(cDltClient):
         connected = None
         error_count = 0
         if not self.is_udp_multicast:
-            logger.info("Connecting DLTClient using TCP Connection")
+            if self.verbose:
+                logger.info("Connecting DLTClient using TCP Connection")
             if timeout:
                 end_time = time.time() + timeout
                 while time.time() < end_time:
@@ -939,7 +956,7 @@ class DLTClient(cDltClient):
                             (ctypes.string_at(self.servIP), self.port), timeout=timeout_remaining
                         )
                     except IOError as exc:
-                        if error_count < MAX_LOG_IN_ROW:
+                        if error_count < MAX_LOG_IN_ROW and self.verbose:
                             logger.debug(
                                 "DLT client connect failed to connect to %s:%s : %s", self.servIP, self.port, exc
                             )
@@ -966,14 +983,18 @@ class DLTClient(cDltClient):
                 # connection loss in the main_loop below as described at
                 # http://stefan.buettcher.org/cs/conn_closed.html
                 self._connected_socket = socket.fromfd(self.sock, socket.AF_INET6, socket.SOCK_STREAM)
-            if error_count > MAX_LOG_IN_ROW:
+            if error_count > MAX_LOG_IN_ROW and self.verbose:
                 logger.debug("Surpressed %d messages for failed connection attempts", error_count - MAX_LOG_IN_ROW)
 
         else:
-            logger.info("Connecting DLTClient using UDP Connection")
-            connected = dltlib.dlt_client_connect(ctypes.byref(self), self.verbose)
+            if self.verbose:
+                logger.info("Connecting DLTClient using UDP Connection")
 
-        logger.info("DLT Connection return: %s", connected)
+            connected = dltlib.dlt_client_connect(ctypes.byref(self), self.verbose)
+            self._set_udp_multicast_buffer_size()
+
+        if self.verbose:
+            logger.info("DLT Connection return: %s", connected)
         return connected == DLT_RETURN_OK
 
     def disconnect(self):
@@ -1019,7 +1040,7 @@ class DLTClient(cDltClient):
         if msg.standardheader.htyp & DLT_HTYP_WEID:
             dltlib.dlt_set_storageheader(msg.p_storageheader, msg.headerextra.ecu)
         else:
-            dltlib.dlt_set_storageheader(msg.p_storageheader, ctypes.c_char_p(""))
+            dltlib.dlt_set_storageheader(msg.p_storageheader, ctypes.c_char_p(b""))
 
         return msg
 
@@ -1038,7 +1059,7 @@ class DLTClient(cDltClient):
         if msg.contents.p_standardheader.contents.htyp & DLT_HTYP_WEID:
             dltlib.dlt_set_storageheader(msg.contents.p_storageheader, msg.contents.headerextra.ecu)
         else:
-            dltlib.dlt_set_storageheader(msg.contents.p_storageheader, ctypes.c_char_p(""))
+            dltlib.dlt_set_storageheader(msg.contents.p_storageheader, ctypes.c_char_p(b""))
 
         print(msg.contents)
         return 0
@@ -1048,6 +1069,54 @@ class DLTClient(cDltClient):
         dltlib.dlt_client_register_message_callback(self.msg_callback)
         dltlib.dlt_client_main_loop(ctypes.byref(self), None, self.verbose)
 
+    def _set_udp_multicast_buffer_size(self, custom_fd_buffer_size_bytes=None, custom_buffer_size_bytes=None) -> None:
+        fd_buffer_size = int(self._udp_fd_buffer_size_bytes or custom_fd_buffer_size_bytes or 0)
+        buffer_size_bytes = int(self._udp_buffer_size_bytes or custom_buffer_size_bytes or 0)
+
+        if fd_buffer_size:
+            # Socket options are associated with an open file description. This
+            # means that file descriptors duplicated as a consequence of dup()
+            # (or similar) or fork() share the same set of socket options.
+            #     -- Chapter 61.9 Socket Options.
+            #        The Linux Programming Interface, p.1279
+            #
+            # The buffer size can be changed with a new fd which is created by
+            # dup system call (it's the internal implementation in
+            # `socket.fromfd`), so the code creates a socket instance first
+            # configures  it and directly close it.
+            with socket.fromfd(self.sock, socket.AF_INET, socket.SOCK_DGRAM) as conf_socket:
+                logger.debug("Set UDP Multicast socket buffer size: %s kbytes", fd_buffer_size / 1024)
+                conf_socket.setsockopt(socket.SOL_SOCKET, socket.SO_RCVBUF, fd_buffer_size)
+
+                real_buffer_size = int(conf_socket.getsockopt(socket.SOL_SOCKET, socket.SO_RCVBUF) / 2)
+                if real_buffer_size != fd_buffer_size:
+                    logger.warning(
+                        (
+                            "Failed to set UDP Multicast buffer size. set_size: %s, real_size: %s. "
+                            "Bypass the error and continue"
+                        ),
+                        fd_buffer_size / 1024,
+                        real_buffer_size / 1024,
+                    )
+                    logger.warning(
+                        (
+                            "Please run command `sysctl -w net.core.rmem_max=%s` with root permission to "
+                            "set the maximum size and restart dlt again."
+                        ),
+                        fd_buffer_size,
+                    )
+
+        if buffer_size_bytes:
+            logger.debug("Set UDP Multicast DltReceiver buffer size: %s kbytes", buffer_size_bytes / 1024)
+            ret = dltlib.dlt_receiver_init(
+                ctypes.byref(self.receiver), self.sock, self.receiver.type, buffer_size_bytes
+            )
+            if ret < 0:
+                raise RuntimeError(
+                    f"Failed to set UDP Multicast DltReceiver buffer size. return code: {ret}, "
+                    f"buffer_size_bytes: {buffer_size_bytes}"
+                )
+
 
 def py_dlt_file_main_loop(dlt_reader, limit=None, callback=None):
     """Main loop to read dlt messages from dlt file."""
