@@ -1,6 +1,5 @@
 # Copyright (C) 2015. BMW Car IT GmbH. All rights reserved.
 """DLT client helpers"""
-import six
 
 
 class LimitCondition(object):
@@ -57,8 +56,7 @@ class ContinuousnessChecker(object):
 
 def bytes_to_str(byte_or_str):
     """Return string from bytes"""
-    if six.PY3:
-        if isinstance(byte_or_str, bytes):
-            return byte_or_str.decode('utf8')
+    if isinstance(byte_or_str, bytes):
+        return byte_or_str.decode("utf8", errors="replace")
 
     return str(byte_or_str)
